==> kamailio_5.4.4.orig.tar.gz: kamailio-5.4.4/src/modules/cdp/utils.h <==
/*
 * Copyright (C) 2012 Smile Communications, jason.penton@smilecoms.com
 * Copyright (C) 2012 Smile Communications, richard.good@smilecoms.com
 *
 * The initial version of this code was written by Dragos Vingarzan
 * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
 * Fruanhofer Institute. It was and still is maintained in a separate
 * branch of the original SER. We are therefore migrating it to
 * Kamailio/SR and look forward to maintaining it from here on out.
 * 2011/2012 Smile Communications, Pty. Ltd.
 * ported/maintained/improved by
 * Jason Penton (jason(dot)penton(at)smilecoms.com and
 * Richard Good (richard(dot)good(at)smilecoms.com) as part of an
 * effort to add full IMS support to Kamailio/SR using a new and
 * improved architecture
 *
 * NB: Alot of this code was originally part of OpenIMSCore,
 * FhG Fokus.
 * Copyright (C) 2004-2006 FhG Fokus
 * Thanks for great work! This is an effort to
 * break apart the various CSCF functions into logically separate
 * components. We hope this will drive wider use. We also feel
 * that in this way the architecture is more complete and thereby easier
 * to manage in the Kamailio/SR environment
 *
 * This file is part of Kamailio, a free SIP server.
 *
 * Kamailio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * Kamailio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef __CDP_UTILS_H_
#define __CDP_UTILS_H_

#include "../../core/dprint.h"
#include "../../core/str.h"
#include "../../core/mem/mem.h"
#include "../../core/mem/shm_mem.h"
#include "../../core/locking.h"
#include "../../core/pt.h"
#include "../../core/rand/kam_rand.h"
#include "sem.h"

#ifndef LOG_NO_MEM
	#define LOG_NO_MEM(mem_type,data_len) \
		LM_ERR("%s:%s()[%d]: Out of %s memory allocating %lx bytes\n",\
			__FILE__,__FUNCTION__,__LINE__, \
			mem_type,(unsigned long)data_len);
#endif


#define shm_str_dup_macro(dst,src)\
{\
	(dst).s = shm_malloc((src).len+1);\
	if (!(dst).s){LOG_NO_MEM("shm",(src).len+1);}\
	else {memcpy((dst).s,(src).s,(src).len);(dst).s[(src).len]=0;(dst).len=(src).len;}\
}

#endif /*UTILS_H_*/

==> kamailio_5.8.4.orig.tar.gz: kamailio-5.8.4/src/modules/cdp/utils.h <==
/*
 * Copyright (C) 2012 Smile Communications, jason.penton@smilecoms.com
 * Copyright (C) 2012 Smile Communications, richard.good@smilecoms.com
 *
 * The initial version of this code was written by Dragos Vingarzan
 * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
 * Fruanhofer Institute. It was and still is maintained in a separate
 * branch of the original SER. We are therefore migrating it to
 * Kamailio/SR and look forward to maintaining it from here on out.
 * 2011/2012 Smile Communications, Pty. Ltd.
 * ported/maintained/improved by
 * Jason Penton (jason(dot)penton(at)smilecoms.com and
 * Richard Good (richard(dot)good(at)smilecoms.com) as part of an
 * effort to add full IMS support to Kamailio/SR using a new and
 * improved architecture
 *
 * NB: Alot of this code was originally part of OpenIMSCore,
 * FhG Fokus.
 * Copyright (C) 2004-2006 FhG Fokus
 * Thanks for great work! This is an effort to
 * break apart the various CSCF functions into logically separate
 * components. We hope this will drive wider use. We also feel
 * that in this way the architecture is more complete and thereby easier
 * to manage in the Kamailio/SR environment
 *
 * This file is part of Kamailio, a free SIP server.
 *
 * Kamailio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * Kamailio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef __CDP_UTILS_H_
#define __CDP_UTILS_H_

#include "../../core/dprint.h"
#include "../../core/str.h"
#include "../../core/mem/mem.h"
#include "../../core/mem/shm_mem.h"
#include "../../core/locking.h"
#include "../../core/pt.h"
#include "../../core/rand/kam_rand.h"
#include "sem.h"

#ifndef LOG_NO_MEM
#define LOG_NO_MEM(mem_type, data_len)                                       \
	LM_ERR("%s:%s()[%d]: Out of %s memory allocating %lx bytes\n", __FILE__, \
			__FUNCTION__, __LINE__, mem_type, (unsigned long)data_len);
#endif


#define shm_str_dup_macro(dst, src)              \
	{                                            \
		(dst).s = shm_malloc((src).len + 1);     \
		if(!(dst).s) {                           \
			LOG_NO_MEM("shm", (src).len + 1);    \
		} else {                                 \
			memcpy((dst).s, (src).s, (src).len); \
			(dst).s[(src).len] = 0;              \
			(dst).len = (src).len;               \
		}                                        \
	}

#endif /*UTILS_H_*/
